==> seedsui-react-5.0.7.tgz: package/es/Container/Container.js <==
var _excluded = ["lazyLoad", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import ImgLazy from './../ImgLazy';
import ContainerPull from './ContainerPull'; // 容器

var Container = forwardRef(function (_ref, ref) {
  var lazyLoad = _ref.lazyLoad,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  }); // 图片懒加载

  var lazyInstance = useRef(null);
  useEffect(function () {
    if (lazyLoad !== 'scroll' && lazyLoad !== 'queue') return;

    if (lazyInstance.current) {
      lazyInstance.current.load();
    } else {
      lazyInstance.current = new ImgLazy({
        overflowContainer: rootRef.current,
        load: lazyLoad
      });
      lazyInstance.current.load();
    }
  }, [children]); // eslint-disable-line

  if (typeof (others === null || others === void 0 ? void 0 : others.onTopRefresh) === 'function' || typeof (others === null || others === void 0 ? void 0 : others.onBottomRefresh) === 'function') {
    return /*#__PURE__*/React.createElement(ContainerPull, _extends({
      ref: rootRef,
      children: children
    }, others));
  }

  return /*#__PURE__*/React.createElement("article", _extends({
    ref: rootRef
  }, others, {
    className: "container" + (others.className ? ' ' + others.className : '')
  }), children);
});
export default Container;

==> seedsui-react-5.5.1.tgz: package/es/Container/Container.js <==
var _excluded = ["lazyLoad", "children"];

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useEffect } from 'react';
import ImgLazy from './../ImgLazy';
import ContainerPull from './ContainerPull';
/**
 * @deprecated since version 5.4.9
 * 请使用Body
 */

var Container = forwardRef(function (_ref, ref) {
  var lazyLoad = _ref.lazyLoad,
      children = _ref.children,
      others = _objectWithoutPropertiesLoose(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  }); // 图片懒加载

  var lazyInstance = useRef(null);
  useEffect(function () {
    if (lazyLoad !== 'scroll' && lazyLoad !== 'queue') return;

    if (lazyInstance.current) {
      lazyInstance.current.load();
    } else {
      lazyInstance.current = new ImgLazy({
        overflowContainer: rootRef.current,
        load: lazyLoad
      });
      lazyInstance.current.load();
    }
  }, [children]); // eslint-disable-line

  if (typeof (others === null || others === void 0 ? void 0 : others.onTopRefresh) === 'function' || typeof (others === null || others === void 0 ? void 0 : others.onBottomRefresh) === 'function') {
    return /*#__PURE__*/React.createElement(ContainerPull, _extends({
      ref: rootRef,
      children: children
    }, others));
  }

  return /*#__PURE__*/React.createElement("article", _extends({
    ref: rootRef
  }, others, {
    className: "container" + (others.className ? ' ' + others.className : '')
  }), children);
});
export default Container;
